package org.openxma.dsl.reference.dtoassembler.model.impl;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import org.openxma.dsl.reference.base.model.impl.BaseEntityImpl;
import org.openxma.dsl.reference.dtoassembler.model.Child;
import org.openxma.dsl.reference.dtoassembler.model.Parent;

public abstract class ParentGenImpl extends BaseEntityImpl implements Parent {
	protected String firstName;
	protected String lastName;
	protected Set<Child> children;
    
	public String getFirstName() {
		return this.firstName;
	}
	
	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getLastName() {
		return this.lastName;
	}
	
	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public Set<Child> getChildren() {
		if (this.children == null) {
            this.children = new HashSet<Child>();
        }
        return Collections.unmodifiableSet(this.children);
	}
	
	public boolean hasChildren() {
		return children != null && !children.isEmpty();
	}

	public void addChildren(Child children) {
		if (children == null) {
			throw new IllegalArgumentException("parameter 'children' must not be null");
		}
		if (!getChildren().contains(children)) {
			this.children.add(children);
			children.setParent(this);
		}
	}

	public void removeChildren(Child children) {
		if (children == null) {
			throw new IllegalArgumentException("parameter 'children' must not be null");
		}
		if (getChildren().contains(children)) {
            this.children.remove(children);
			children.setParent(null);
		}
	}

    public void removeAllChildren() {
        if (this.children != null) {
            this.children.clear();
        }
    }
	
    @Override
    public String toString() {
    	StringBuilder toStringBuilder = new StringBuilder("Parent [");
    	toStringBuilder.append(super.toString()).append(",");
        toStringBuilder.append("firstName=").append(getFirstName()).append(",");
        toStringBuilder.append("lastName=").append(getLastName());
        return toStringBuilder.append("]").toString();
    }
}
