package org.openxma.dsl.snippets.ui.panels.client;

import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Shell;
import at.spardat.xma.component.EmbeddableComponent;
import at.spardat.xma.page.Scaler;
import at.spardat.xma.session.XMASessionClient;

/**
 * This class implements the generic client part of Panels.
 * It provides the mapping between typeIds and classnames
 * of all pages in the component.
 *
 */
abstract public class PanelsGen extends EmbeddableComponent implements IPanels {

    /**
     * Initializes the PanelsGen. This method is called
     * by the XMA-Runtime.
     *
     * @param session the XMASession, this PanelsGen belongs to.
     */
    public PanelsGen (XMASessionClient session) {
        super (session, false);
    }

    /** the unique typeId for the page PanelPage */
    public static final short PanelPageClass = 0;
    /** the unique typeId for the page VPanelPage */
    public static final short VPanelPageClass = 1;
    /** the unique typeId for the page HPanelPage */
    public static final short HPanelPageClass = 2;
    /** the unique typeId for the page ArrangedPanels */
    public static final short ArrangedPanelsClass = 3;

    /**
    * Array of the classnames of all pages in
    * this component. The typeIds are used as indices
    * into this array.
     */
    static final String[] modelClasses = {
        "PanelPage",
        "VPanelPage",
        "HPanelPage",
        "ArrangedPanels"
    };

    /**
    * Gets the short classname for the given typeId of
    * a page in this component. The short classname does
    * not contain the package.
    *
    * @param typeId the unique typeId
    * @return the short classname
     */
    static public String getShortModelClass(short typeId) {
        return modelClasses[typeId];
    }

    /**
    * Gets the full classname for the given typeId of
    * a page in this component.
    *
    * @param typeId the unique typeId
    * @return the full classname
     */
    public String getModelClass(short typeId) {
        return "org.openxma.dsl.snippets.ui.panels.client."+modelClasses[typeId];
    }

    /**
     * Invokes the Panels. This method is a default
     * implementation, which invokes the first dialog page of the component.
     * Modeled init functions are called by this method.
     *
     * @param parentComposite a composite of the calling page. In most
     *     cases it will be a shell. It my be null.
     */
    public void invoke(Composite parentComposite) {
        PanelPage panelPage_generatedXMAPage;
        if(parentComposite instanceof Shell) {
            panelPage_generatedXMAPage = new PanelPage(this,(Shell)parentComposite);
        } else {
            panelPage_generatedXMAPage = new PanelPage(this);
        }
        panelPage_generatedXMAPage.invoke();
    }

    /*
     * returns the scaler used for this page
    */
    final protected Scaler getScaler() {
        // TODO: Update code to current generator version?
        return null;
    }    
    
    /**
     * Gives the URI of the help for this component
     * This URI is relative to the download-URI of the component
     * @return the relative URI of the help for this component
     */
    public String getHelpUri() {
        return "help/org/openxma/dsl/snippets/ui/panels/Panels.html";
    }

}
